==> recipes-0.10.0.tar.xz: recipes-0.10.0/data/recipes.db.h <==
#if 0

N_("Non-knead buns")
N_("Very quick fresh bread for breakfast with 5 minutes of work.")
N_("Preparation:")
N_("Mix together all of the ingredients in a large bowl into a thick porridge-like dough. Do not knead the dough, just mix it together. ")
N_("Cover and leave to rise in room temperature for 8-12 hours. This can be done for example the previous night so you can bake them in the morning.")
N_("Baking:")
N_("Heat your oven to 250 degrees Celsius. ")
N_("The dough will be more than double in size and full of bubbles and very sticky. Pour a generous amount of flour on your baking surface so it doesn't stick, and pour the dough over it.")
N_("Form the dough into a thick snake, about the diameter of your arm and cut bun-sized pieces with scissors onto the baking sheet.")
N_("Bake until nice and brown, this will take approximately 15 minutes.")
N_("You can substitute half of the wheat flour with oats, seeds or different kind of flour if you want variety.")
N_("Traditional South Indian Tomato Chicken Curry, Fast Version")
N_("A quick and easy version of a traditional South Indian chicken curry dish, learned from a Mallu immigrant and cook.")
N_("Preparation:")
N_("Cube 5 large chicken breasts (about 4 cups) into 1-1.5 inch cubes")
N_("Thinly slice 1 large onion, chopping the final quarter of the onion")
N_("Chop 2 medium tomatoes into large chunks")
N_("Cooking:")
N_("In a large pot, heat 1 tbsp olive oil at medium/medium-high heat. Once oil is hot, add mustard seeds and fry until they pop (cover the pot to prevent splashing). Too much heat will burn the seeds.")
N_("Once seeds have popped, turn down the heat to medium and add thinly sliced onion. Cover to retain moisture. Cook until translucent, stirring frequently. Add small amounts of water as necessary.")
N_("While onions are cooking, blend remaining chopped onion and tomatoes to create a puree. Add water if necessary.")
N_("Once onions are translucent, increase heat to medium-high and immediately add all spices. Toast for 30 seconds until aromatic.")
N_("Add the rest of the olive oil (2 more tbsp) and tomato and onion puree from blender. Cook until raw smell of onions and tomatoes is going — up to 5 minutes.")
N_("Turn down heat to medium. Add chopped chicken breast, cover, and allow to slowly cook. Add small amounts of water as necessary to achieve desired sauce consistency. (Chicken will release its own fat and water into the sauce, so wait a few minutes before adding extra.)")
N_("Can be served immediately or left to marinate in curry sauce, then reheated. Serve with rice or chapati/heated flour tortilla.")
N_("To make a more full-flavored curry, try adding garam masala (ground cardamom, cloves, fennel seeds, and nutmeg), along with fresh curry leaves.")
N_("Rosemary Scalloped Potatoes")
N_("A holiday twist on a classic American comfort food dish. Easy to make and sure to please.")
N_("Substitutions and conversions:")
N_("5 potatoes = 5 cans sliced potatoes")
N_("1 stick butter = 8 Tbsp butter")
N_("4 cloves garlic = 1/2 tsp powdered garlic")
N_("8 oz cream cheese = 1 pouch")
N_("1 cup half and half = one small carton")
N_("1 cup grated parmesan = 1 small bag")
N_("Preheat oven to 350°F.")
N_("Butter a 13x9 baking dish.")
N_("Into buttered baking dish:")
N_("- Add 5 thinly sliced (use a mandoline) russet potatoes, or 5 cans rinsed pre-sliced potatoes.")
N_("- Salt and pepper potatoes (more will be added to creamy mixture later), stir lightly to separate slices.")
N_("In a frying pan on medium to medium-low heat:")
N_("- Melt 1 stick of butter.")
N_("- Add 1 chopped onion, garlic. Saute until translucent (about 5 minutes).")
N_("- Add 8 oz cream cheese (quartered to help it melt faster).")
N_("- When cream cheese is melted, add 1 cup half and half.")
N_("- Add salt and pepper to taste. (Don't be afraid to use more salt than you expect — it's a large dish, and potatoes need flavoring.) Recommend 1/2 Tbsp salt and 1/2 tsp pepper.")
N_("- Add finely chopped fresh rosemary and chopped green onions.")
N_("- Add 1/2 cup grated parmesan and melt into mixture.")
N_("To bake:")
N_("- Pour mixture over potatoes, stirring a bit to help the sauce cover everywhere. If using canned potatoes, be sure to separate the slices which are otherwise stuck together and prevent the mixture from seeping in.")
N_("- Spread remaining cheese over top to provide a nice texture and cheese flavoring.")
N_("- Bake for 1 to 1 1/2 hours, until liquid is bubbling and top cheese is browning.")
N_("Note: Don't be afraid to use extra parmesan cheese and cream (half and half). This recipe makes just enough sauce, but extra creaminess never hurts, especially if you're using canned sliced potatoes. Garlic can be increased to taste, but be careful not to let the garlic overtake the rosemary.")
N_("Classic Chicken Noodle Soup")
N_("A simple take on a typical American meal.")
N_("If you haven't butchered the chicken, do so. Depending on how meaty you want the soup, you can use more or less of the butchered parts (I recommend the dark leg meat for the soup). Use the remaining parts for another dish.")
N_("Wash the celery, carrots and herbs. Slice the carrots and celery. Coarsely chop the onion. Prepare the herbs using kitchen twine in a bouquet garni.")
N_("In a large pot, add the chicken, the stock, 2 carrots, 1 stalk of celery, the onion and the bouquet garni. Fill the pot with water to cover the chicken. Bring to a boil and simmer for at least 2 hours.")
N_("Using a cheese cloth strainer, strain the soup into another pot. Remove meat from the bones, gather any loose chicken and add it to the strained soup. Discard the bones and cooked vegetables.")
N_("Add the remaining carrots and celery to the soup. Bring to a boil and simmer for at least one hour. Season with salt and pepper to taste.")
N_("Add noodles and simmer for about 10 minutes, until the noodles are done.")
N_("Pizzaburger")
N_("Tomato dough with hamburger and cheese topping")
N_("Dissolve yeast in warm water. Let stand for 2 minutes.")
N_("Add 1/2 cup tomato sauce, oil, salt, 1 tsp chili powder, and sugar. Mix well.")
N_("Gradually stir in flour. Dough will become sticky.")
N_("Optional: Let rise covered in a warm place for about an hour.")
N_("Brown diced onion and hamburger in frying pan.")
N_("Add remaining 1 1/2 cups tomato sauce, salt, pepper, and 2 tsp chili powder.")
N_("Remove from heat.")
N_("Spread dough on greased cookie sheet (will be somewhat springy and pull back as it is spread out).")
N_("Top with hamburger mixture and cover with cheese slices.")
N_("Bake at 400 for 20 to 30 minutes until dough is baked.")
N_("Pineapple Upside Down Cake with Hot Buttered Rum Sauce")
N_("This is a delicious, boozy update on a classic cake. The combination of rum and pineapple gives it a distinctively Caribbean flavour.")
N_("Preheat the oven to 175°C/gas mark 4.")
N_("Grease a round 20cm cake tin.")
N_("Line the bottom of the tin with as many whole pineapple rings as will fit. Cut the remaining rings in half and use them to line the sides of the tin.")
N_("Crack the eggs into a bowl and add the caster sugar. Whisk until pale and light (an electric whisk is good for this, but not essential).")
N_("In a different bowl, combine the flour and baking powder, and then sift into the egg and sugar mixture, mixing as you go.")
N_("Melt the butter and combine with the milk,  rum and vanilla extract. Zest half the lemon and add.")
N_("Mix the wet mixture into the rest of the ingredients.")
N_("Poor the cake mixture into the cake tin and bake for around 40 minutes, until the top is light brown and an inserted skewer comes out clean.")
N_("Leave the cake to cool for 5 minutes, then turn out on to a rack to cool completely.")
N_("When it's time to eat, make the sauce: combine the muscovado sugar and cream in a saucepan and heat until the sugar has dissolved. Add the rum and simmer until it has thickened a little, then add the butter and let it melt into the sauce.")
N_("Pour the hot sauce over the cake and serve.")
N_("Pan pizza")
N_("Pizza is an all-time favorite.")
N_("Put the flour, yeast, water and olive oil in a bowl and stir it up with your hands or a spoon until there's no dry flour left, and let it be.")
N_("Cover the bowl tightly in plastic wrap and let it sit at room temperature overnight. ")
N_("The next day it should have rosen quite a bit. Dump it all out onto a floured surface, then divide it into balls.")
N_("Spread olive oil in a 10-inch cast iron skillet or round cake pan and place a dough ball in the middle.")
N_("Rub the dough ball around and flip it a couple times until it is completely coated in oil and the oil completely coats the bottom and sides of the pan. Cover in plastic, and let it sit for another couple of hours without touching it.")
N_("The dough should have spread on it own (takes about 2 hours). Lift the sides of the dough to let big air bubbles out.")
N_("Put in the oven at 280°C. (or as hot as your oven goes) for about 15 minutes. Peek underneath and if your pizza is a little pale, you can finish on the stovetop directly over medium heat until it is as dark and crisp as you like it.")
N_("Wholesome Crackers")
N_("Crackers are a fulfilling alternative snack and keeps your stomach going. Crackers consist of seeds, oat and flour. The recipe described here is very flexible. You can use whichever seeds, nuts and flour types you may have. I've personally tried almonds, sesame seeds, chia seeds, rye grains, millet and  buckwheat.")
N_("Turn on the oven at 473,15 K (200 °C). Mix all dry ingredients (seeds, flour, oatmeal, baking powder and salt) together. Mix oil. Then add water gradually while mixing until the dough is firm and pasty. If you add too much water, the dough will end up sticking too much to the baking paper.")
N_("Cut a sheet of baking paper at the size of a baking tray and place the dough on it. Cut another sheet of baking paper and put on top. Use a rolling pin on top of the second baking sheet to flatten the dough. Make the dough as thing as possible. Afterwards, take off the second sheet. Bring forth a knife and cut creases from horizontally and vertically to form squares (see example on the picture). Optionally decorate with extra seeds on top before inserting into the preheated oven.")
N_("Wait for the crackers to become crisp, this takes around 17 minutes. You can check if they are done by touching the crackers or by pulling up a bit in the baking sheet and see if the crackers in the middle still bends.  The crackers take on a yellow golden color when they are done.")
N_("Take out the crackers and leave them on the kitchen table to cool down for a few minutes.")
N_("Tofu ‘Egg’ Scramble")
N_("This vegan breakfast staple is perfect on a lazy saturday morning.")
N_("Chop the onion. Open up the tofu package and slice it up, then crumble with your hands.")
N_("Sautee the onion, tofu, and peppers for 3-5 minutes using the vegan butter.")
N_("Turn heat down to medium and add the rest of the ingredients – cook for 5-7 minutes more.")
N_("Donauwellen")
N_("Donauwellen is a popular German cake with chocolate, vanilla cream and cherries. The name is due to the fact that the dough typically forms a wavy pattern.")
N_("Mix the butter until it is creamy. Add sugar and eggs​<a href=\"image:1\">①</a>. Mix the flour with the baking powder and mix it in. Separate a third of the dough and add the cocoa powder to it​<a href=\"image:2\">②</a>.")
N_("Spread the light dough on a buttered baking sheet. Put the dark dough on top​<a href=\"image:4\">④</a>. Use a fork to make a wavy pattern. Spread the dried cherries on top of the dough​<a href=\"image:6\">⑥</a>.")
N_("Bake for 30 minutes at 200 °C.")
N_("Use the milk, sugar and pudding to cook vanilla pudding and let it cool down while stirring it frequently. Slowly add spoonfuls of the butter, which should be at room temperature. Spread the butter cream on the cooled cake.")
N_("Melt the chocolate frosting in a hot water bath and sprinkle it on top.")
N_("Gingered Carrot Soup")
N_("A nutritious vegan soup that can be made relatively quickly")
N_("Place carrots in large saucepan with water, cover, bring to a boil. Lower heat, simmer until very tender (10-15 minutes). While carrots are cooking, saute in olive oil all the onions, 5 minutes, then add garlic, ginger, salt, and spices. When all is well mingled, stir in lemon juice. Use food processor or blender to puree everything together (including all the toasted cashews). If you like a more textured soup, only half puree.")
N_("Garnish with parsley, chives, mint or scallions if you want. Top with cayenne pepper if you want a spicier soup. You can also add any leftover grains like rice, barley, couscous, etc. at the last minute.")
N_("This is my Aunt Wendy's recipe.")


#endif

==> recipes-0.12.0.tar.xz: recipes-0.12.0/data/recipes.db.h <==
#if 0

N_("White fish for people who dont like fish.")
N_("It is a fantastic dish for those of us that dont love fish, but know we have to eat it to stay healthy.")
N_("The key to get this dish good is to have high temperature on the stove when first frying the fish. Then turn it down after the initial fry.")
N_("Set the stove to high (8/10), then put a good amount of oil in it. Any type of oil will do.")
N_("Remove bone and skin from the fish (if any), and add salt and pepper. Give the stove some minutes to get really hot. Then put the fish in. 2-3 min on each side.")
N_("Turn the temperature down to low (3/10). Add two spoons of butter, some thyme, rosemary and garlic. When the butter have melted, use a spoon to poor the melted butter and spice mix over the fish fillet.")
N_("After about 5 minutes your fish will be done. You can serve it with potatoes, rice, or noodles. Everything works.")
N_("Grumbeerekiechle")
N_("Traditional potato hash from Alsace. Usually served with lettuce, sometimes with smoked salmon.")
N_("[image:1]Peel and grate the potatoes. Peel and slice the onions. Mix with the rest of the ingredients in a large bowl.")
N_("Put a frying pan on the hob at medium heat with a bit of oil.")
N_("[image:2]Form thin patties in the pan and brown them on both sides.")
N_("[image:0]Serve hot. Can be kept in a fridge and reheated in a micro-wave oven.")
N_("Savoury cakes")
N_("This savoury cakes can be served as appetizers or as main course. There are several variations that you can bake with the same base depending on your mood and tastes. Quite common at French parties.")
N_("Prepare the batter: melt butter in a large bowl, then mix with the eggs, flour and yeast in a bowl.")
N_("Add the ingredients matching the variation you chose, preferably sliced or diced to turn them into small bits, and mix again. Try coming up with your own variations!")
N_("Pour the batter in a loaf tin.")
N_("[timer:00:40:00]Put in the oven at 180°C for 40 minutes.")
N_("[image:1]Serve cold, cut in slices or cubes that people will get with a toothpick.")
N_("Tagliatelle alla Romana")
N_("Pasta is one of my favourite things in the world, and this is one of my favourity pasta dishes. It's gutsy Italian food at its best.")
N_("It's important to have good quality chicken livers for this recipe - get free range organic if possible. You can use dried pasta if you're unable to get fresh.")
N_("Rinse the chicken livers and cut out any out any bits of sinew. Dry and season with salt and pepper.")
N_("Finely chop the red onion.")
N_("Melt half the butter in a frying pan, then add the olive oil and cook the onion until soft, without letting it brown.")
N_("Add the livers to the pan and fry until lightly browned. Then add the tomatoes and cook on a low heat for 20 minutes, stirring occasionally.")
N_("Put a deep pan of water on to boil and add a good pinch of salt to the water.")
N_("Remove the livers from the pan and chop finely. Then add back to the sauce and continue to cook. Check for seasoning and add more salt and pepper if necessary.")
N_("Cook the pasta for 3 minutes if fresh (or put on earlier and follow packet instructions if using dry pasta).")
N_("Drain the pasta, retaining a cup of the pasta water. Add the pasta to the sauce along with the remaining butter. Mix and cook on a low heat for several minutes, to allow the pasta to absorb the sauce.")
N_("If the sauce needs loosening, add a bit of the pasta cooking water.")
N_("Serve with plenty of black pepper.")
N_("Non-knead buns")
N_("Very quick fresh bread for breakfast with 5 minutes of work.")
N_("[image:0]Preparation:")
N_("[image:1]Mix together all of the ingredients in a large bowl into a thick porridge-like dough. Do not knead the dough, just mix it together. ")
N_("Cover and leave to rise in room temperature for 8-12 hours. This can be done for example the previous night so you can bake them in the morning.")
N_("Baking:")
N_("Heat your oven to 250 degrees Celsius.")
N_("[image:3]The dough will be more than double in size and full of bubbles and very sticky. Pour a generous amount of flour on your baking surface so it doesn't stick, and pour the dough over it.")
N_("[image:4]Form the dough into a thick snake, about the diameter of your arm and cut bun-sized pieces with scissors onto the baking sheet.")
N_("[timer:00:15:00]Bake until nice and brown, this will take approximately 15 minutes.")
N_("[image:5]You can substitute half of the wheat flour with oats, seeds or different kind of flour if you want variety.")
N_("Traditional South Indian Tomato Chicken Curry, Fast Version")
N_("A quick and easy version of a traditional South Indian chicken curry dish, learned from a Mallu immigrant and cook.")
N_("Preparation:")
N_("Cube 5 large chicken breasts (about 4 cups) into 1-1.5 inch cubes")
N_("Thinly slice 1 large onion, chopping the final quarter of the onion")
N_("Chop 2 medium tomatoes into large chunks")
N_("Cooking:")
N_("In a large pot, heat 1 tbsp olive oil at medium/medium-high heat. Once oil is hot, add mustard seeds and fry until they pop (cover the pot to prevent splashing). Too much heat will burn the seeds.")
N_("Once seeds have popped, turn down the heat to medium and add thinly sliced onion. Cover to retain moisture. Cook until translucent, stirring frequently. Add small amounts of water as necessary.")
N_("While onions are cooking, blend remaining chopped onion and tomatoes to create a puree. Add water if necessary.")
N_("Once onions are translucent, increase heat to medium-high and immediately add all spices. Toast for 30 seconds until aromatic.")
N_("Add the rest of the olive oil (2 more tbsp) and tomato and onion puree from blender. Cook until raw smell of onions and tomatoes is going — up to 5 minutes.")
N_("Turn down heat to medium. Add chopped chicken breast, cover, and allow to slowly cook. Add small amounts of water as necessary to achieve desired sauce consistency. (Chicken will release its own fat and water into the sauce, so wait a few minutes before adding extra.)")
N_("Can be served immediately or left to marinate in curry sauce, then reheated. Serve with rice or chapati/heated flour tortilla.")
N_("To make a more full-flavored curry, try adding garam masala (ground cardamom, cloves, fennel seeds, and nutmeg), along with fresh curry leaves.")
N_("Rosemary Scalloped Potatoes")
N_("A holiday twist on a classic American comfort food dish. Easy to make and sure to please.")
N_("Substitutions and conversions:")
N_("5 potatoes = 5 cans sliced potatoes")
N_("1 stick butter = 8 Tbsp butter")
N_("4 cloves garlic = 1/2 tsp powdered garlic")
N_("8 oz cream cheese = 1 pouch")
N_("1 cup half and half = one small carton")
N_("1 cup grated parmesan = 1 small bag")
N_("Preheat oven to 350°F.")
N_("Butter a 13x9 baking dish.")
N_("Into buttered baking dish:")
N_("- Add 5 thinly sliced (use a mandoline) russet potatoes, or 5 cans rinsed pre-sliced potatoes.")
N_("- Salt and pepper potatoes (more will be added to creamy mixture later), stir lightly to separate slices.")
N_("In a frying pan on medium to medium-low heat:")
N_("- Melt 1 stick of butter.")
N_("- Add 1 chopped onion, garlic. Saute until translucent (about 5 minutes).")
N_("- Add 8 oz cream cheese (quartered to help it melt faster).")
N_("- When cream cheese is melted, add 1 cup half and half.")
N_("- Add salt and pepper to taste. (Don't be afraid to use more salt than you expect — it's a large dish, and potatoes need flavoring.) Recommend 1/2 Tbsp salt and 1/2 tsp pepper.")
N_("- Add finely chopped fresh rosemary and chopped green onions.")
N_("- Add 1/2 cup grated parmesan and melt into mixture.")
N_("To bake:")
N_("- Pour mixture over potatoes, stirring a bit to help the sauce cover everywhere. If using canned potatoes, be sure to separate the slices which are otherwise stuck together and prevent the mixture from seeping in.")
N_("- Spread remaining cheese over top to provide a nice texture and cheese flavoring.")
N_("- Bake for 1 to 1 1/2 hours, until liquid is bubbling and top cheese is browning.")
N_("Note: Don't be afraid to use extra parmesan cheese and cream (half and half). This recipe makes just enough sauce, but extra creaminess never hurts, especially if you're using canned sliced potatoes. Garlic can be increased to taste, but be careful not to let the garlic overtake the rosemary.")
N_("Classic Chicken Noodle Soup")
N_("A simple take on a typical American meal.")
N_("If you haven't butchered the chicken, do so. Depending on how meaty you want the soup, you can use more or less of the butchered parts (I recommend the dark leg meat for the soup). Use the remaining parts for another dish.")
N_("Wash the celery, carrots and herbs. Slice the carrots and celery. Coarsely chop the onion. Prepare the herbs using kitchen twine in a bouquet garni.")
N_("In a large pot, add the chicken, the stock, 2 carrots, 1 stalk of celery, the onion and the bouquet garni. Fill the pot with water to cover the chicken. Bring to a boil and simmer for at least 2 hours.")
N_("Using a cheese cloth strainer, strain the soup into another pot. Remove meat from the bones, gather any loose chicken and add it to the strained soup. Discard the bones and cooked vegetables.")
N_("Add the remaining carrots and celery to the soup. Bring to a boil and simmer for at least one hour. Season with salt and pepper to taste.")
N_("Add noodles and simmer for about 10 minutes, until the noodles are done.")
N_("Pizzaburger")
N_("Tomato dough with hamburger and cheese topping")
N_("Dissolve yeast in warm water. Let stand for 2 minutes.")
N_("Add 1/2 cup tomato sauce, oil, salt, 1 tsp chili powder, and sugar. Mix well.")
N_("Gradually stir in flour. Dough will become sticky.")
N_("Optional: Let rise covered in a warm place for about an hour.")
N_("Brown diced onion and hamburger in frying pan.")
N_("Add remaining 1 1/2 cups tomato sauce, salt, pepper, and 2 tsp chili powder.")
N_("Remove from heat.")
N_("Spread dough on greased cookie sheet (will be somewhat springy and pull back as it is spread out).")
N_("Top with hamburger mixture and cover with cheese slices.")
N_("Bake at 400 for 20 to 30 minutes until dough is baked.")
N_("Pineapple Upside Down Cake with Hot Buttered Rum Sauce")
N_("This is a delicious, boozy update on a classic cake. The combination of rum and pineapple gives it a distinctively Caribbean flavour.")
N_("Preheat the oven to 175°C/gas mark 4.")
N_("Grease a round 20cm cake tin.")
N_("Line the bottom of the tin with as many whole pineapple rings as will fit. Cut the remaining rings in half and use them to line the sides of the tin.")
N_("Crack the eggs into a bowl and add the caster sugar. Whisk until pale and light (an electric whisk is good for this, but not essential).")
N_("In a different bowl, combine the flour and baking powder, and then sift into the egg and sugar mixture, mixing as you go.")
N_("Melt the butter and combine with the milk,  rum and vanilla extract. Zest half the lemon and add.")
N_("Mix the wet mixture into the rest of the ingredients.")
N_("Poor the cake mixture into the cake tin and bake for around 40 minutes, until the top is light brown and an inserted skewer comes out clean.")
N_("Leave the cake to cool for 5 minutes, then turn out on to a rack to cool completely.")
N_("When it's time to eat, make the sauce: combine the muscovado sugar and cream in a saucepan and heat until the sugar has dissolved. Add the rum and simmer until it has thickened a little, then add the butter and let it melt into the sauce.")
N_("Pour the hot sauce over the cake and serve.")
N_("Pan pizza")
N_("Pizza is an all-time favorite.")
N_("Put the flour, yeast, water and olive oil in a bowl and stir it up with your hands or a spoon until there's no dry flour left, and let it be.")
N_("Cover the bowl tightly in plastic wrap and let it sit at room temperature overnight. ")
N_("The next day it should have rosen quite a bit. Dump it all out onto a floured surface, then divide it into balls.")
N_("Spread olive oil in a 10-inch cast iron skillet or round cake pan and place a dough ball in the middle.")
N_("Rub the dough ball around and flip it a couple times until it is completely coated in oil and the oil completely coats the bottom and sides of the pan. Cover in plastic, and let it sit for another couple of hours without touching it.")
N_("The dough should have spread on it own (takes about 2 hours). Lift the sides of the dough to let big air bubbles out.")
N_("Put in the oven at 280°C. (or as hot as your oven goes) for about 15 minutes. Peek underneath and if your pizza is a little pale, you can finish on the stovetop directly over medium heat until it is as dark and crisp as you like it.")
N_("Wholesome Crackers")
N_("Crackers are a fulfilling alternative snack and keeps your stomach going. Crackers consist of seeds, oat and flour. The recipe described here is very flexible. You can use whichever seeds, nuts and flour types you may have. I've personally tried almonds, sesame seeds, chia seeds, rye grains, millet and  buckwheat.")
N_("Turn on the oven at 473,15 K (200 °C). Mix all dry ingredients (seeds, flour, oatmeal, baking powder and salt) together. Mix oil. Then add water gradually while mixing until the dough is firm and pasty. If you add too much water, the dough will end up sticking too much to the baking paper.")
N_("Cut a sheet of baking paper at the size of a baking tray and place the dough on it. Cut another sheet of baking paper and put on top. Use a rolling pin on top of the second baking sheet to flatten the dough. Make the dough as thing as possible. Afterwards, take off the second sheet. Bring forth a knife and cut creases from horizontally and vertically to form squares (see example on the picture). Optionally decorate with extra seeds on top before inserting into the preheated oven.")
N_("Wait for the crackers to become crisp, this takes around 17 minutes. You can check if they are done by touching the crackers or by pulling up a bit in the baking sheet and see if the crackers in the middle still bends.  The crackers take on a yellow golden color when they are done.")
N_("Take out the crackers and leave them on the kitchen table to cool down for a few minutes.")
N_("Tofu ‘Egg’ Scramble")
N_("This vegan breakfast staple is perfect on a lazy saturday morning.")
N_("Chop the onion. Open up the tofu package and slice it up, then crumble with your hands.")
N_("Sautee the onion, tofu, and peppers for 3-5 minutes using the vegan butter.")
N_("Turn heat down to medium and add the rest of the ingredients – cook for 5-7 minutes more.")
N_("Donauwellen")
N_("Donauwellen is a popular German cake with chocolate, vanilla cream and cherries. The name is due to the fact that the dough typically forms a wavy pattern.")
N_("[image:1]Mix the butter until it is creamy. Add sugar and egg.")
N_("[image:2]Mix the flour with the baking powder and mix it in. Separate a third of the dough and add the cocoa powder to it.")
N_("[image:4]Spread the light dough on a buttered baking sheet. Put the dark dough on top.")
N_("[image:4]Use a fork to make a wavy pattern.")
N_("[image:6]Spread the dried cherries on top of the dough.")
N_("[timer:00:30:00]Bake for 30 minutes at 200 °C.")
N_("Use the milk, sugar and pudding to cook vanilla pudding and let it cool down while stirring it frequently. Slowly add spoonfuls of the butter, which should be at room temperature.")
N_("[image:8]Spread the butter cream on the cooled cake.")
N_("[image:9]Melt the chocolate frosting in a hot water bath and sprinkle it on top.")
N_("Gingered Carrot Soup")
N_("A nutritious vegan soup that can be made relatively quickly")
N_("Place carrots in large saucepan with water, cover, bring to a boil. Lower heat, simmer until very tender (10-15 minutes). While carrots are cooking, saute in olive oil all the onions, 5 minutes, then add garlic, ginger, salt, and spices. When all is well mingled, stir in lemon juice. Use food processor or blender to puree everything together (including all the toasted cashews). If you like a more textured soup, only half puree.")
N_("Garnish with parsley, chives, mint or scallions if you want. Top with cayenne pepper if you want a spicier soup. You can also add any leftover grains like rice, barley, couscous, etc. at the last minute.")
N_("This is my Aunt Wendy's recipe.")


#endif
